@@ -1,4 +1,4 @@
-__version__ = "1.7.3"
+__version__ = "1.8.1"
 
 import logging
 from urllib.parse import urlparse, parse_qs
@@ -291,6 +291,9 @@ class QRonosClient(object):
             stage=None,
             tracker_stage=None,
             tracker_stages=None,
+            interval_start_date=None,
+            interval_end_date=None,
+            fields=None,
             page_size=None,
             page=None,
     ):
@@ -306,6 +309,9 @@ class QRonosClient(object):
             :param stage: The ID of a stage (Stage model)
             :param tracker_stage: The ID of a tracker stage (TrackerStage model)
             :param tracker_stages: A list of tracker stage ids (TrackerStage model)
+            :param interval_start_date: Date beginning for time period to fetch history in iso-8601 format
+            :param interval_end_date: Date end for time period to fetch history in iso-8601 format
+            :param fields: A list of  attributes names of ItemStage
             :param page_size: Number of items per page
             :param page: The link for next page
         :return: Item stages history
@@ -330,6 +336,14 @@ class QRonosClient(object):
         elif tracker_stages:
             post_data["tracker_stages"] = tracker_stages
 
+        if interval_start_date:
+            post_data["interval_start_date"] = interval_start_date
+        if interval_end_date:
+            post_data["interval_end_date"] = interval_end_date
+
+        if fields:
+            post_data["fields"] = fields
+
         if page:
             params.update(parse_qs(urlparse(page).query))
         if page_size:
